==> otyacraftengine-fabric-3.6.0-alpha.1-sources.jar: dev/felnull/otyacraftengine/client/gui/screen/OEContainerBasedScreen.java <==
package dev.felnull.otyacraftengine.client.gui.screen;


import com.mojang.blaze3d.systems.RenderSystem;
import dev.felnull.otyacraftengine.inventory.OEBaseMenu;
import java.util.UUID;
import net.minecraft.class_1661;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_342;
import net.minecraft.class_364;
import net.minecraft.class_4587;
import net.minecraft.class_465;
import net.minecraft.class_757;

public abstract class OEContainerBasedScreen<T extends OEBaseMenu> extends class_465<T> implements InstructionScreen, OEBaseScreen {
    protected static final class_310 mc = class_310.method_1551();
    protected final UUID id = UUID.randomUUID();
    protected int bgTextureWidth = 256;
    protected int bgTextureHeight = 256;

    public OEContainerBasedScreen(T abstractContainerMenu, class_1661 inventory, class_2561 component) {
        super(abstractContainerMenu, inventory, component);
    }


    @Override
    public void method_25394(class_4587 poseStack, int i, int j, float f) {
        this.method_25420(poseStack);
        super.method_25394(poseStack, i, j, f);
        this.method_2380(poseStack, i, j);
    }

    @Override
    protected void method_2389(class_4587 poseStack, float f, int i, int j) {
        if (getBackGrandTexture() != null) {
            RenderSystem.setShader(class_757::method_34542);
            RenderSystem.setShaderColor(1.0F, 1.0F, 1.0F, 1.0F);
            RenderSystem.setShaderTexture(0, getBackGrandTexture());
            method_25290(poseStack, field_2776, field_2800, 0, 0, this.field_2792, this.field_2779, bgTextureWidth, bgTextureHeight);
        }
    }

    protected abstract class_2960 getBackGrandTexture();


    @Override
    public boolean method_25403(double d, double e, int i, double f, double g) {
        boolean flag1 = super.method_25403(d, e, i, f, g);
        boolean flag2 = this.method_25399() != null && this.method_25397() && i == 0 && this.method_25399().method_25403(d, e, i, f, g);
        return flag1 & flag2;
    }

    @Override
    protected void method_37432() {
        super.method_37432();
        for (class_364 child : method_25396()) {
            if (child instanceof class_342 editBox) {
                editBox.method_1865();
            }
        }
    }

    @Override
    public boolean method_25404(int i, int j, int k) {
        if (i == 256)
            mc.field_1724.method_7346();

        for (class_364 child : method_25396()) {
            if (child instanceof class_342 editBox) {
                if (editBox.method_25404(i, j, k) || editBox.method_20315())
                    return true;
            }
        }

        return super.method_25404(i, j, k);
    }

    @Override
    public void onInstructionReturn(String name, class_2487 data) {

    }

    @Override
    public UUID getInstructionID() {
        return id;
    }
}

==> otyacraftengine-fabric-3.7.0-alpha.1-sources.jar: dev/felnull/otyacraftengine/client/gui/screen/OEContainerBasedScreen.java <==
package dev.felnull.otyacraftengine.client.gui.screen;


import com.mojang.blaze3d.systems.RenderSystem;
import dev.felnull.otyacraftengine.inventory.OEBaseMenu;
import java.util.UUID;
import net.minecraft.class_1661;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_342;
import net.minecraft.class_364;
import net.minecraft.class_465;

public abstract class OEContainerBasedScreen<T extends OEBaseMenu> extends class_465<T> implements InstructionScreen, OEBaseScreen {
    protected static final class_310 mc = class_310.method_1551();
    protected final UUID id = UUID.randomUUID();
    protected int bgTextureWidth = 256;
    protected int bgTextureHeight = 256;

    public OEContainerBasedScreen(T abstractContainerMenu, class_1661 inventory, class_2561 component) {
        super(abstractContainerMenu, inventory, component);
    }


    @Override
    public void method_25394(class_332 guiGraphics, int i, int j, float f) {
        this.method_25420(guiGraphics);
        super.method_25394(guiGraphics, i, j, f);
        this.method_2380(guiGraphics, i, j);
    }

    @Override
    protected void method_2389(class_332 guiGraphics, float f, int i, int j) {
        if (getBackGrandTexture() != null) {
           /* RenderSystem.setShader(GameRenderer::getPositionTexShader);
            RenderSystem.setShaderColor(1.0F, 1.0F, 1.0F, 1.0F);
            RenderSystem.setShaderTexture(0, getBackGrandTexture());
          blit(poseStack, leftPos, topPos, 0, 0, this.imageWidth, this.imageHeight, bgTextureWidth, bgTextureHeight);*/
            guiGraphics.method_25290(getBackGrandTexture(), field_2776, field_2800, 0, 0, this.field_2792, this.field_2779, bgTextureWidth, bgTextureHeight);
        }
    }

    protected abstract class_2960 getBackGrandTexture();


    @Override
    public boolean method_25403(double d, double e, int i, double f, double g) {
        boolean flag1 = super.method_25403(d, e, i, f, g);
        boolean flag2 = this.method_25399() != null && this.method_25397() && i == 0 && this.method_25399().method_25403(d, e, i, f, g);
        return flag1 & flag2;
    }

    @Override
    protected void method_37432() {
        super.method_37432();
        for (class_364 child : method_25396()) {
            if (child instanceof class_342 editBox) {
                editBox.method_1865();
            }
        }
    }

    @Override
    public boolean method_25404(int i, int j, int k) {
        if (i == 256)
            mc.field_1724.method_7346();

        for (class_364 child : method_25396()) {
            if (child instanceof class_342 editBox) {
                if (editBox.method_25404(i, j, k) || editBox.method_20315())
                    return true;
            }
        }

        return super.method_25404(i, j, k);
    }

    @Override
    public void onInstructionReturn(String name, class_2487 data) {

    }

    @Override
    public UUID getInstructionID() {
        return id;
    }
}
